#!/usr/bin/env python

class Nekogirl():
    def __init__(self, name):
        self.name = name

    def 名字(self):
        return self.name

    def 喵喵喵(self):
        print('喵喵喵')

    def 变(self):
        print('变好了')


if __name__ == '__main__':
    my_nekogirl = Nekogirl('sweety')
